<?php
/**
 * Created by Shipox.
 * User: Shipox
 * Date: 11/8/2017
 * Time: 2:41 PM
 */

class Shipox_Shipping_Method extends WC_Shipping_Method
{
    /**
     * Shipox_Shipping_Method constructor.
     */
    public function __construct()
    {
        parent::__construct();

        $this->id = 'wing';
        $this->method_title = __('Shipox', 'shipox');
        $this->enabled = $this->get_option('enabled');
        $this->apply_tax = $this->get_option('apply_tax');
        $this->init();

//        $this->supports = array(
//            'shipping-zones'
//        );

        $this->title = isset($this->settings['title']) ? $this->settings['title'] : __('Shipox Shipping', 'shipox');
    }

    /**
     *
     */
    private function init()
    {
        $this->init_form_fields();
        $this->init_settings();

        add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
//        add_filter('woocommerce_shipping_methods', array($this, 'shipox_shipping_method'));
    }

    /**
     * Define settings field for this shipping
     * @return void
     */
    function init_form_fields()
    {
        $this->form_fields = array(

            'enabled' => array(
                'title' => __('Enable', 'shipox'),
                'type' => 'checkbox',
                'description' => __('Enable this shipping.', 'shipox'),
                'default' => 'yes'
            ),

            'title' => array(
                'title' => __('Title', 'winshipoxg'),
                'type' => 'text',
                'description' => __('Title to be display on site', 'shipox'),
                'default' => __('Shipox Shipping', 'shipox')
            ),

            'weight' => array(
                'title' => __('Weight (kg)', 'shipox'),
                'type' => 'number',
                'description' => __('Maximum allowed weight', 'shipox'),
                'default' => 100
            ),

            'availability' => array(
                'title' => __('Methods availability', 'shipox'),
                'type' => 'select',
                'default' => 'all',
                'class' => 'availability wc-enhanced-select',
                'options' => array(
                    'all' => __('All allowed countries', 'shipox'),
                    'specific' => __('Specific Countries', 'shipox')
                )
            ),

            'countries' => array(
                'title' => __('Specific Countries', 'shipox'),
                'type' => 'multiselect',
                'class' => 'wc-enhanced-select',
                'css' => 'width: 450px;',
                'default' => '',
                'options' => WC()->countries->get_shipping_countries(),
                'custom_attributes' => array(
                    'data-placeholder' => __('Select some countries', 'shipox')
                )
            ),

            'apply_tax' => array(
                'title' => __('Apply Tax to the Shipping Prices', 'shipox'),
                'type' => 'checkbox',
                'description' => __('If enabled, tax will be applied to the Shipox Shipping Prices', 'shipox'),
                'default' => ''
            ),
        );
    }


    /**
     *  Calculate Shipping
     * @param array $package
     */
    public function calculate_shipping($package = array())
    {
        global $WCFMmp;

        if (!$this->enabled) return;

        // TODO if WCFM is active, hide shipping method on Checkout Page
        if($WCFMmp) return;

        $baseLocation = wc_get_base_location();

        $marketplaceCountry = shipox()->wing['settings-helper']->getCountryCode();
        $marketplaceCurrency = shipox()->wing['settings-helper']->getCurrency();

        if (get_woocommerce_currency() !== $marketplaceCurrency || $baseLocation["country"] !== $marketplaceCountry) return;

        $orderConfig = shipox()->wing['options']['order_config'];
        $merchantAddress = shipox()->wing['options']['merchant_address'];

        $address = apply_filters('shipox_get_shipping_address', $package['destination']);

        if ($this->get_option('availability') == 'specific' && !in_array($address["country"], $this->get_option('countries')))
            return;

        $weight = 0;
        foreach ($package['contents'] as $item_id => $values)
            if ($values['quantity'] > 0 && $values['data']->needs_shipping())
                $weight += intval($values['quantity']) * floatval($values['data']->get_weight());

        $weight = wc_get_weight($weight, 'kg');

        if ($orderConfig['order_default_weight'] > 0) {
            $weight = intval($orderConfig['order_default_weight']);
        }

        $country = shipox()->wing['api-helper']->getCountryWingId($address["country"]);
        $marketplaceIntAvailability = shipox()->wing['settings-helper']->getInternationalAvailability();
        $isDomestic = shipox()->wing['api-helper']->isDomesticByCode($address['country']);

        if ($orderConfig['order_international_availability'] == 0 && !$marketplaceIntAvailability && !$isDomestic)
            return;

        $merchantLatLong = explode(",", $merchantAddress['merchant_lat_long']);

        $priceArray = array();
        if (!empty($merchantLatLong)) {
            $customerLatLonAddress = shipox()->wing['api-helper']->getAddressLocationByAddress($address);

            if (!empty($customerLatLonAddress)) {
                // New Model
                $priceRequestData = array(
                    'dimensions.domestic' => $isDomestic,
                    'dimensions.length' => 10,
                    'dimensions.width' => 10,
                    'dimensions.weight' => $weight,
                    'dimensions.unit' => 'METRIC',
                    'from_country_id' => shipox()->wing['settings-helper']->getCountryId(),
                    'to_country_id' => $country["id"],
                    'from_latitude' => trim($merchantLatLong[0]),
                    'from_longitude' => trim($merchantLatLong[1]),
                    'to_latitude' => $customerLatLonAddress[0],
                    'to_longitude' => $customerLatLonAddress[1],
                    'service_types' => implode(",", $orderConfig['order_default_courier_type']),
                );

                $priceList = shipox()->api->getPackagePricesV2($priceRequestData);

                if ($priceList['success']) {
                    $list = $priceList['data']['list'];

                    foreach ($list as $listItem) {
                        $priceItem = $listItem['price'];
                        $name = $listItem['name'];
                        if (isset($listItem['supplier'])) {
                            $name = $listItem['supplier']['name'] . " - " . $listItem['name'];
                        }
                        $method = $listItem['id'] . '-' . $priceItem['id'] . '-' . $weight . '-' . ($isDomestic ? '1' : '0');
                        $response['type'] = 'success';
                        $priceArray[$method] = array('label' => $name, 'amount' => $priceItem['total']);
                    }
                }

            }
        }

        if (isset($priceArray) && !empty($priceArray)) {
            foreach ($priceArray as $key => $value) {
                $rate = array(
                    'id' => $this->id . '_' . $key,
                    'label' => $value['label'],
                    'cost' => $value['amount'],
                    'taxes' => $this->apply_tax == 'yes' ? '' : false,
                    'calc_tax' => 'per_order'
                );
                $this->add_rate($rate);
            }
        }
    }

    /**
     * @param $methods
     * @return mixed
     */
    public function shipox_shipping_method($methods)
    {
        $methods['wing'] = 'Shipox_Shipping_Method';
        return $methods;
    }
}

if(class_exists('WC_Shipping_Method')) {
    new Shipox_Shipping_Method();
}