<?php
/**
 * Created by PhpStorm.
 * User: umidakhm
 * Date: 10/17/2018
 * Time: 3:31 PM
 */

namespace shipox_includes;


/**
 * Class Shipox_Order_Helper
 * @package includes
 */
class Shipox_Order_Helper
{
    /**
     * Shipox_Order_Helper constructor.
     */
    public function __construct()
    {
        add_filter('shipox_get_customer_geo_location', array($this, 'shipox_get_customer_geo_location'), 10, 2);
//        add_filter('shipox_get_shipping_address', array($this, 'shipox_get_shipping_address'), 10, 1);
    }

    /**
     * @param $order
     * @param $shipping_country
     * @return array
     */
    function check_wing_order_create_availability($order, $shipping_country) {
        $baseLocation = wc_get_base_location();
        $orderConfig = shipox()->wing['options']['order_config'];
        $marketplaceCountry = shipox()->wing['settings-helper']->getCountryCode();
        $marketplaceCountryName = shipox()->wing['settings-helper']->getCountryName();
        $marketplaceCurrency = shipox()->wing['settings-helper']->getCurrency();
        $marketplaceIntAvailability = shipox()->wing['settings-helper']->getInternationalAvailability();

        $response = array(
            'success' => false,
            'message' => null,
        );

        if ($baseLocation["country"] == $marketplaceCountry) {
            $currency = $order->get_currency();

            if ($currency == $marketplaceCurrency) {
                if ($orderConfig['order_international_availability'] == 0 && !$marketplaceIntAvailability && $shipping_country !== $marketplaceCountry) {
                    shipox()->log->write($order->get_id() . " - International is turned off", 'error');
                    $response['message'] = __("Shipox: International Order is turned off", 'wing');
                } else {
                    $response['success'] = true;
                }
            } else {
                shipox()->log->write($order->get_id() . " - CURRENCY should be only ". $marketplaceCurrency, 'error');
                $response['message'] = __("Shipox: CURRENCY should be only ". $marketplaceCurrency, 'wing');
            }
        } else {
            shipox()->log->write($order->get_id() . " - Delivery only for ". $marketplaceCountryName, 'error');
            $response['message'] = __("Shipox: Service only within ".$marketplaceCountryName, 'wing');
        }

        return $response;
    }

    /**
     * Update Woocommerce Order Status (If status selected from Shipox Options)
     * @param $order
     * @param $message
     */
    function updateWCOrderStatus($order, $message) {
        $serviceConfig = shipox()->wing['options']['service_config'];

        if(isset($serviceConfig['next_status']) && !empty(trim($serviceConfig['next_status']))) {
            $nextStatus = trim($serviceConfig['next_status']);
            $order->update_status($nextStatus, $message);
        }

        $order->add_order_note($message, 1);
    }

    /**
     * @param $response_array
     * @param $order_wc
     * @return mixed
     */
    function shipox_get_customer_geo_location($response_array, $order_wc) {
        if( !is_a( $order_wc, 'WC_Order' ) ) return $response_array;

        $user_lat = $order_wc->get_meta('_wcfmmp_user_location_lat', true);
        $user_lon = $order_wc->get_meta('_wcfmmp_user_location_lng', true);

        if(!empty($user_lat) && !empty($user_lon)) {
            $response_array = [$user_lat, $user_lon];
        }

        return $response_array;
    }
}